/**
 * This grid is used as a superclass for some array-like classes. It is 1
 * dimensional.<br>
 * Spatially periodic boundary conditions are applied, meaning that the grid is
 * viewed as a circle, with the leftmost and rightmost cells each acting as the
 * others neighbour.
 * 
 * @author TineL
 * @version 1.0, 2007-05-29
 * @since 1.0
 */
public abstract class Abstract1DGrid {

  private int size=0;

  /**
   * Creates <code>Abstract1DGrid</code> with the specified size.
   * 
   * @param size the grid size.
   * @since 1.0
   */
  public Abstract1DGrid(int size) {
    this.size=size;
  }

  /**
   * @return the grid size.
   * @since 1.0
   */
  public int size() {
    return this.size;
  }

  /**
   * @param index the index of the element in the grid.
   * @return the index of the left element (periodic boundary).
   * @since 1.0
   */
  public int getLeftIndex(int index) {
    return (index-1+size())%size();
  }

  /**
   * @param index the index of the element in the grid.
   * @return the index of the right element (periodic boundary).
   * @since 1.0
   */
  public int getRightIndex(int index) {
    return (index+1+size())%size();
  }
}
