/**
 * The 1 dimensional grid for storing cell fitnesses with some utilities.
 * 
 * @author TineL
 * @version 1.1, 2007-05-29
 * @since 1.0
 */
public class Fitnesses extends Abstract1DGrid {

  /** Array of fitnesses. */
  private int[] fitnesses;

  /**
   * Creates <code>Fitnesses</code> with the specified size. All fitnesses are
   * set to 0.
   * 
   * @param size the grid size (number of fitnesses).
   * @since 1.0
   */
  public Fitnesses(int size) {
    super(size);
    this.fitnesses=new int[size];
  }

  /**
   * @param index the fitness index.
   * @return the fitness.
   * @since 1.0
   */
  public int get(int index) {
    return fitnesses[index];
  }

  /**
   * Increments the fitness at the specified index for one.
   * 
   * @param index the fitness index.
   * @since 1.0
   */
  public void inc(int index) {
    fitnesses[index]++;
  }

  /**
   * @return the sum of all fitnesses in the grid.
   * @since 1.0
   */
  public int sum() {
    int sum=0;
    for (int i=0; i<size(); i++) {
      sum+=get(i);
    }
    return sum;
  }

  /**
   * @param index the fitness index.
   * @return the left fitness.
   * @since 1.0
   */
  public int getLeft(int index) {
    return get(getLeftIndex(index));
  }

  /**
   * @param index the fitness index.
   * @return the right fitness.
   * @since 1.0
   */
  public int getRight(int index) {
    return get(getRightIndex(index));
  }

  /**
   * Computes how many fitnesses around the specified one has bigger values.
   * Neighbour fitnesses are one left and one right.
   * 
   * @param index the fitness index.
   * @return the number of bigger fitnesses around (only 0, 1 or 2).
   * @since 1.0
   */
  public int biggerNeighbours(int index) {
    int num=0;
    if (isLeftBigger(index)) num++;
    if (isRightBigger(index)) num++;
    return num;
  }

  /**
   * @param index the fitness index.
   * @return <code>true</code> if left fitness is bigger.
   * @since 1.0
   */
  public boolean isLeftBigger(int index) {
    return getLeft(index)>get(index);
  }

  /**
   * @param index the fitness index.
   * @return <code>true</code> if right fitness is bigger.
   * @since 1.0
   */
  public boolean isRightBigger(int index) {
    return getRight(index)>get(index);
  }

  /*
   * @since 1.0
   */
  public String toString() {
    String out="Fitnesses=[";
    for (int i=0; i<size()-1; i++) {
      out+=get(i)+"|";
    }
    out+=get(size()-1)+"]";
    return out;
  }
}
